@@ -50,6 +50,7 @@ G_BEGIN_DECLS
 GS_DEFINE_CLEANUP_FUNCTION0(GArray*, gs_local_array_unref, g_array_unref)
 GS_DEFINE_CLEANUP_FUNCTION0(GBytes*, gs_local_bytes_unref, g_bytes_unref)
 GS_DEFINE_CLEANUP_FUNCTION0(GChecksum*, gs_local_checksum_free, g_checksum_free)
+GS_DEFINE_CLEANUP_FUNCTION0(GDateTime*, gs_local_date_time_unref, g_date_time_unref)
 GS_DEFINE_CLEANUP_FUNCTION0(GDir*, gs_local_dir_close, g_dir_close)
 GS_DEFINE_CLEANUP_FUNCTION0(GError*, gs_local_free_error, g_error_free)
 GS_DEFINE_CLEANUP_FUNCTION0(GHashTable*, gs_local_hashtable_unref, g_hash_table_unref)
@@ -73,6 +74,7 @@ GS_DEFINE_CLEANUP_FUNCTION(void*, gs_local_free, g_free)
 #define _cleanup_timer_destroy_ __attribute__ ((cleanup(gs_local_destroy_timer)))
 #define _cleanup_free_ __attribute__ ((cleanup(gs_local_free)))
 #define _cleanup_checksum_free_ __attribute__ ((cleanup(gs_local_checksum_free)))
+#define _cleanup_date_time_unref_ __attribute__ ((cleanup(gs_local_date_time_unref)))
 #define _cleanup_error_free_ __attribute__ ((cleanup(gs_local_free_error)))
 #define _cleanup_list_free_ __attribute__ ((cleanup(gs_local_free_list)))
 #define _cleanup_plugin_list_free_ __attribute__ ((cleanup(gs_local_free_plugin_list)))
