@@ -30,6 +30,13 @@ try:
                                    'org.gtk.Application')
     proxy.call_sync('Activate', GLib.Variant('(a{sv})', ({},)), 0, -1, None)
 
+    doDelay(1)
+    try:
+        shopping_button = app.child(name=u'Let\u2019s Go Shopping', retry=False)
+        shopping_button.click()
+    except tree.SearchError:
+        print "not first-run, moving on"
+
     doDelay(1)
     assert (len(app.children) == 1)
 
